@@ -18,7 +18,7 @@ getTimeDouble = realToFrac <$> getPOSIXTime
 
 import Control.Applicative ((<$>))
 
-import System.Posix.Clock
+import System.Clock
 
 -- | returns a monotonic time in seconds
 getTimeDouble :: IO Double
